==> huaweicloudsdksms-3.1.71-py2.py3-none-any.whl: huaweicloudsdksms/v3/model/show_privacy_agreements_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowPrivacyAgreementsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'flag': 'bool'
    }

    attribute_map = {
        'flag': 'flag'
    }

    def __init__(self, flag=None):
        """ShowPrivacyAgreementsResponse

        The model defined in huaweicloud sdk

        :param flag: 查询用户是否同意隐私协议
        :type flag: bool
        """
        
        super(ShowPrivacyAgreementsResponse, self).__init__()

        self._flag = None
        self.discriminator = None

        if flag is not None:
            self.flag = flag

    @property
    def flag(self):
        """Gets the flag of this ShowPrivacyAgreementsResponse.

        查询用户是否同意隐私协议

        :return: The flag of this ShowPrivacyAgreementsResponse.
        :rtype: bool
        """
        return self._flag

    @flag.setter
    def flag(self, flag):
        """Sets the flag of this ShowPrivacyAgreementsResponse.

        查询用户是否同意隐私协议

        :param flag: The flag of this ShowPrivacyAgreementsResponse.
        :type flag: bool
        """
        self._flag = flag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowPrivacyAgreementsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksms-3.1.147-py2.py3-none-any.whl: huaweicloudsdksms/v3/model/show_privacy_agreements_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowPrivacyAgreementsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'flag': 'bool'
    }

    attribute_map = {
        'flag': 'flag'
    }

    def __init__(self, flag=None):
        r"""ShowPrivacyAgreementsResponse

        The model defined in huaweicloud sdk

        :param flag: 查询用户是否同意隐私协议
        :type flag: bool
        """
        
        super(ShowPrivacyAgreementsResponse, self).__init__()

        self._flag = None
        self.discriminator = None

        if flag is not None:
            self.flag = flag

    @property
    def flag(self):
        r"""Gets the flag of this ShowPrivacyAgreementsResponse.

        查询用户是否同意隐私协议

        :return: The flag of this ShowPrivacyAgreementsResponse.
        :rtype: bool
        """
        return self._flag

    @flag.setter
    def flag(self, flag):
        r"""Sets the flag of this ShowPrivacyAgreementsResponse.

        查询用户是否同意隐私协议

        :param flag: The flag of this ShowPrivacyAgreementsResponse.
        :type flag: bool
        """
        self._flag = flag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowPrivacyAgreementsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
